@@ -1,7 +1,7 @@
 from typing import List, Generator
 
 from nltk.util import ngrams
-from numpy import zeros, ndarray, argmax
+from numpy import zeros, ndarray, argmax, full
 
 from ffast.poincare.token import Token
 from ffast.poincare.tokens import Tokens
@@ -37,14 +37,17 @@ class Tokeniser:
                     continue 
                 raw_token = ' '.join(words[index_start:index_end])
                 normalised_token = PREPROCESSOR.normalise(text=' '.join(ngram))
-                if normalised_token in VOCABULARY:
-                    id = VOCABULARY.index(normalised_token)
-                    vector = VECTORS[id]
+                if raw_token in self.special_tokens:
+                    id = Poincare.SIZE_VOCABULARY.value + self.special_tokens.index(raw_token)
+                    vector = full(Poincare.SIZE_VECTOR.value,-1)
                 elif raw_token in VOCABULARY:
                     id = VOCABULARY.index(raw_token)
                     vector = VECTORS[id]
+                elif normalised_token in VOCABULARY:
+                    id = VOCABULARY.index(normalised_token)
+                    vector = VECTORS[id]
                 else:
-                    id = Poincare.SIZE_VOCABULARY.value + self.special_tokens.index(raw_token) if raw_token in self.special_tokens else len(self)
+                    id = len(self)
                     vector = zeros(Poincare.SIZE_VECTOR.value)
                     normalised_token = Poincare.UNKNOWN.value
                 if id <= Poincare.SIZE_VOCABULARY.value or ngram_size==1:
